@@ -11,7 +11,7 @@
 import collections
 import logging
 import re
-from xml.etree import ElementTree
+from xml.etree import ElementTree  # nosec nosemgrep
 
 from common import sge
 from common.remote_command_executor import RemoteCommandExecutor
@@ -184,7 +184,8 @@ def _run_qstat(full_format=False, hostname_filter=None, job_state_filter=None):
     if full_format:
         command += " -f"
     if hostname_filter:
-        command += " -l hostname={0}".format(hostname_filter)
+        short_name = hostname_filter.split(".")[0]
+        command += " -l hostname={0}".format(short_name)
     if job_state_filter:
         command += " -s {0}".format(job_state_filter)
     return check_sge_command_output(command)
@@ -206,7 +207,7 @@ def get_jobs_info(hostname_filter=None, job_state_filter=None):
     if not output:
         return []
 
-    root = ElementTree.fromstring(output)
+    root = ElementTree.fromstring(output)  # nosec
     job_info = root.findall(".//job_list")
     return [SgeJob.from_xml(ElementTree.tostring(host)) for host in job_info]
 
